@@ -1,10 +1,11 @@
 use ndarray::{array, Array2};
 use ndarray_npy::{ReadNpyError, ReadNpyExt, WriteNpyError, WriteNpyExt};
 use std::fs::File;
+use std::io::BufWriter;
 
 fn write_example() -> Result<(), WriteNpyError> {
     let arr: Array2<i32> = array![[1, 2, 3], [4, 5, 6]];
-    let writer = File::create("array.npy")?;
+    let writer = BufWriter::new(File::create("array.npy")?);
     arr.write_npy(writer)?;
     Ok(())
 }
